pub struct RawStridedMut<'a, T> { /* private fields */ }Expand description
Borrowed raw strided output layout.
This is the mutable counterpart to RawStridedRef. It avoids allocating
owned shape/stride metadata in prepared replay paths.
Implementations
Sourceimpl<'a, T> RawStridedMut<'a, T>
impl<'a, T> RawStridedMut<'a, T>
Sourcepub fn new(
data: &'a mut [T],
dims: &'a [usize],
strides: &'a [isize],
offset: isize,
) -> Result<RawStridedMut<'a, T>, StridedError>
pub fn new( data: &'a mut [T], dims: &'a [usize], strides: &'a [isize], offset: isize, ) -> Result<RawStridedMut<'a, T>, StridedError>
Create a raw strided output after validating reachable offsets.
Sourcepub unsafe fn new_unchecked(
data: &'a mut [T],
dims: &'a [usize],
strides: &'a [isize],
offset: isize,
) -> RawStridedMut<'a, T>
pub unsafe fn new_unchecked( data: &'a mut [T], dims: &'a [usize], strides: &'a [isize], offset: isize, ) -> RawStridedMut<'a, T>
Create a raw strided output without bounds checking.
Safety
The caller must ensure every index reachable by dims/strides from
offset lies inside data, and no aliases violate mutable access.
pub fn data(&self) -> &[T]
pub fn data_mut(&mut self) -> &mut [T]
pub fn dims(&self) -> &'a [usize]
pub fn strides(&self) -> &'a [isize]
pub fn offset(&self) -> isize
pub fn ptr(&self) -> *const T
pub fn as_mut_ptr(&mut self) -> *mut T
Sourcepub fn as_view(&self) -> StridedView<'_, T>
pub fn as_view(&self) -> StridedView<'_, T>
Convert to an immutable owning-metadata view.
This is for compatibility paths. Hot prepared paths should use the raw accessors directly and avoid this conversion.
Sourcepub fn as_view_mut(&mut self) -> StridedViewMut<'_, T>
pub fn as_view_mut(&mut self) -> StridedViewMut<'_, T>
Convert to a mutable owning-metadata view.
This is for compatibility paths. Hot prepared paths should use the raw accessors directly and avoid this conversion.